#
# spec file for package kservice
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Full KF5 version (e.g. 5.33.0)
%{!?_kf5_version: %global _kf5_version %{version}}
# Last major and minor KF5 version (e.g. 5.33)
%{!?_kf5_bugfix_version: %define _kf5_bugfix_version %(echo %{_kf5_version} | awk -F. '{print $1"."$2}')}
%define qt5_version 5.15.2
%bcond_without released
Name:           kservice
Version:        5.115.0
Release:        150600.1.3
Summary:        Plugin framework for desktop services
License:        LGPL-2.1-or-later
URL:            https://www.kde.org
Source:         %{name}-%{version}.tar.xz
%if %{with released}
Source1:        %{name}-%{version}.tar.xz.sig
Source2:        frameworks.keyring
%endif
# PATCH-FIX-OPENSUSE kservice-desktop-translations.patch
Patch0:         kservice-desktop-translations.patch
# PATCH-FIX-OPENSUSE dont-show-yast-modules-in-the-applications-menu.patch -- hide the YaST modules from the application menu
Patch1:         dont-show-yast-modules-in-the-applications-menu.patch
BuildRequires:  bison
BuildRequires:  extra-cmake-modules >= %{_kf5_version}
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  cmake(KF5Config) >= %{_kf5_version}
BuildRequires:  cmake(KF5CoreAddons) >= %{_kf5_version}
BuildRequires:  cmake(KF5DBusAddons) >= %{_kf5_version}
BuildRequires:  cmake(KF5DocTools) >= %{_kf5_version}
BuildRequires:  cmake(KF5I18n) >= %{_kf5_version}
BuildRequires:  cmake(Qt5Concurrent) >= %{qt5_version}
BuildRequires:  cmake(Qt5DBus) >= %{qt5_version}
BuildRequires:  cmake(Qt5Test) >= %{qt5_version}
BuildRequires:  cmake(Qt5Xml) >= %{qt5_version}
Recommends:     kded >= %{_kf5_version}
Obsoletes:      libKF5Service4

%description
Provides a plugin framework for handling desktop services. Services can
be applications or libraries. They can be bound to MIME types or handled by
application specific code.

%package devel
Summary:        Plugin framework for desktop services: Build Environment
Requires:       %{name} = %{version}
Requires:       cmake(KF5Config) >= %{_kf5_version}
Requires:       cmake(KF5CoreAddons) >= %{_kf5_version}

%description devel
Provides a plugin framework for handling desktop services. Services can
be applications or libraries. They can be bound to MIME types or handled by
application specific code. Development files

%lang_package

%prep
%autosetup -p1

%build
%cmake_kf5 -d build -- -DAPPLICATIONS_MENU_NAME="kf5-applications.menu"
%cmake_build

%install
%kf5_makeinstall -C build
%fdupes %{buildroot}

%find_lang %{name} --with-man --all-name

%ldconfig_scriptlets

%files lang -f %{name}.lang

%files
%license LICENSES/*
%{_kf5_libdir}/libKF5Service.so.*
%{_kf5_bindir}/kbuildsycoca5
%dir %{_kf5_servicetypesdir}
%{_kf5_servicetypesdir}/application.desktop
%{_kf5_servicetypesdir}/kplugininfo.desktop
%dir %{_kf5_sysconfdir}/xdg/menus
%{_kf5_sysconfdir}/xdg/menus/kf5-applications.menu
%doc %lang(en) %{_kf5_mandir}/*/kbuildsycoca5.*
%doc %lang(en) %{_kf5_mandir}/*/desktoptojson.*
%{_kf5_debugdir}/*.categories
%{_kf5_debugdir}/*.renamecategories

%files devel
%{_kf5_libdir}/libKF5Service.so
%{_kf5_libdir}/cmake/KF5Service/
%{_kf5_includedir}/
%{_kf5_mkspecsdir}/qt_KService.pri

%changelog
* Thu Feb  8 2024 christophe@krop.fr
- Update to 5.115.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.115.0
- No code change since 5.114.0
* Sat Jan 13 2024 christophe@krop.fr
- Update to 5.114.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.114.0
- No code change since 5.113.0
* Tue Dec  5 2023 christophe@krop.fr
- Update to 5.113.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.113.0
- Changes since 5.112.0:
  * Remove warning about empty Exec field from KService::exec() (kde#430157)
* Mon Nov  6 2023 christophe@krop.fr
- Update to 5.112.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.112.0
- No code change since 5.111.0
* Mon Oct  9 2023 christophe@krop.fr
- Update to 5.111.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.111.0
- Changes since 5.110.0:
  * KService: allow .desktop files without an Exec line (kde#430157)
* Wed Sep  6 2023 christophe@krop.fr
- Update to 5.110.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.110.0
- No code change since 5.109.0
* Tue Aug  8 2023 christophe@krop.fr
- Update to 5.109.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.109.0
- Changes since 5.108.0:
  * Add explicit moc includes to sources for moc-covered headers
* Mon Jul  3 2023 christophe@krop.fr
- Update to 5.108.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.108.0
- Changes since 5.107.0:
  * Remove qt6 CI builds
* Mon Jun  5 2023 christophe@krop.fr
- Update to 5.107.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.107.0
- No code change since 5.106.0
* Sat May  6 2023 christophe@krop.fr
- Update to 5.106.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.106.0
- Changes since 5.105.0:
  * Fix querying actions for service of a service action
  * Parse actions last when creating a service
* Sat Apr  1 2023 christophe@krop.fr
- Update to 5.105.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.105.0
- Changes since 5.104.0:
  * Remove unused include
* Mon Mar  6 2023 christophe@krop.fr
- Update to 5.104.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.104.0
- Changes since 5.103.0:
  * Fix deprecation ifdef
  * Deprecate KService::serviceTypes and KService::hasServiceType
  * application: Add X-SnapInstanceName
  * Add method to query supported protocols for a service
* Wed Feb  8 2023 christophe@krop.fr
- Update to 5.103.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.103.0
- No code change since 5.102.0
* Thu Jan 12 2023 christophe@krop.fr
- Update to 5.102.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.102.0
- Changes since 5.101.0:
  * Allow accessing custom properties of KServiceActions
  * Replace QVariant::Type with QMetaType::Type
  * Deprecate KService::dbusStartupType
* Tue Dec  6 2022 christophe@krop.fr
- Update to 5.101.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.101.0
- Changes since 5.100.0:
  * KApplicationTrader: New method setPreferredService
  * Perform initialization in initialization list
* Tue Nov  8 2022 christophe@krop.fr
- Update to 5.100.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.100.0
- Changes since 5.99.0:
  * Do not warn if KService("") is instantiated
  * .kde-ci.yml: enable static CI builds
  * Add Qt 6 Windows CI
* Sat Oct  1 2022 christophe@krop.fr
- Update to 5.99.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.99.0
- No code change since 5.98.0
* Tue Sep  6 2022 christophe@krop.fr
- Update to 5.98.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.98.0
- Changes since 5.97.0:
  * Add FreeBSD Qt6 CI support
* Sun Aug  7 2022 christophe@krop.fr
- Update to 5.97.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.97.0
- Changes since 5.96.0:
  * Add property def for X-Flatpak key
  * Define HAVE_MMAP to 0 instead of undefining it (kde#456780)
  * KSycocaDict: don't inherit from containers
  * use ksandbox to determine if we are inside a flatpak
* Sun Jul  3 2022 christophe@krop.fr
- Update to 5.96.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.96.0
- Changes since 5.95.0:
  * General code clean up
  * Bump deprecation KF version in ecm_set_disabled_deprecation_versions
  * add aliasfor custom property
  * refresh git-blame-ignore-revs for latest clang-format run
  * automatic clang-format run (clang 14)
* Fri Jun 10 2022 christophe@krop.fr
- Update to 5.95.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.95.0
- Changes since 5.94.0:
  * kbuildsycoca: Ignore last modified time when set to UNIX Epoch (kde#442011)
* Tue May 10 2022 christophe@krop.fr
- Update to 5.94.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.94.0
- Changes since 5.93.0:
  * Add missing KCoreAddons and KConfig to tests
  * Add windows CI
  * KService: Do not link KCoreAddons and KConfig publicly when building without deprecations
  * kservice.h: Wrap public KCoreAddons includes in deprecation macros
  * Add Android to supported platforms in repo metadata
* Sun Apr  3 2022 christophe@krop.fr
- Update to 5.93.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.93.0
- Changes since 5.92.0:
  * Add Android to supported platforms in repo metadata
* Mon Mar  7 2022 christophe@krop.fr
- Update to 5.92.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.92.0
- Changes since 5.91.0:
  * Use :/kservicetypes5 instead of :/kf/kservicetypes5
  * Add Qt6 Android CI
  * Explicitely call KPluginMetaData::fromDesktopFile instead of
    KPluginMetaData(QString fileName) constructor
* Sun Feb  6 2022 christophe@krop.fr
- Update to 5.91.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.91.0
- Changes since 5.90.0:
  * Fix warning (qt6 warning)
  * Utilize ECMDeprecationSettings to manage deprecate Qt/KF API
  * Install kservice_version.h in KService include prefix
  * Add CI qt6 support
  * Make parseLayoutNode function const
  * Make "missing merge tag" error actionable
  * Silence deprecation warnings for implementation of deprecated API & their autotests
* Mon Jan  3 2022 christophe@krop.fr
- Update to 5.90.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.90.0
- Changes since 5.89.0:
  * Wrap KServiceTypeTrader methods to create instances also in KCOREADDONS
    visibility guard
  * Not use toLower on DesktopEntryName
  * QVariant(QVariant::Type) constructor is explicit in Qt6
  * Change the build system to enable building with Qt 6
  * Expand deprecation docs for KServiceTypeTrader
  * Deprecate KServiceTypeTrader class
  * Emit deprecation warning for KServiceType class
  * Deprecate KPluginInfo in favor of KPluginMetaData
* Sat Dec  4 2021 christophe@krop.fr
- Update to 5.89.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.89.0
- Changes since 5.88.0:
  * KPluginInfo: Fix mimetypes that are wildcards not appearing in MimeTypes json value
  * Deprecate KToolInvokation::kdeinitExecWait
  * Deprecate E-Mail and terminal related methods in KToolInvocation
* Sun Nov  7 2021 christophe@krop.fr
- Strip 'Source' URL for faster submissions
* Sun Nov  7 2021 christophe@krop.fr
- Update to 5.88.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.88.0
- Changes since 5.87.0:
  * Use KSERVICE_ENABLE_DEPRECATED_SINCE in header instead of BUILD variant
  * cmake: Remove intermediate copy targets
  * kservice.h: Silence deprecation warnings in inlined, deprecated code
  * Add FreeBSD CI
  * Add Android CI
  * Don't use kdoctools on Android
  * Fix CI deps for Android
* Sun Oct  3 2021 christophe@krop.fr
- Update to 5.87.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.87.0
- Changes since 5.86.0:
  * Add Gitlab CI configuration
  * Deprecate KAutostart class
  * Deprecate KService::parentApp
  * Deprecate KService::pluginKeyword property
* Wed Sep 15 2021 christophe@krop.fr
- Drop the unneeded baselibs.conf.
* Mon Sep  6 2021 christophe@krop.fr
- Update to 5.86.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.86.0
- Changes since 5.85.0:
  * We depend against c++-17 so we can use qOverload directly
  * Add support for PrefersNonDefaultGPU desktop key
  * replace "MacOSX" with "macOS"
  * Deprecate plugin instanciation methods in KService/KServiceTypeTrader
  * Port QStringRef (deprecated) to QStringView
  * Point docs to KPluginMetaData/KPluginFactory instead of KPluginLoader
  * kbuildsycoca: port away from KCrash, using our own signal handler
* Fri Aug  6 2021 christophe@krop.fr
- Update to 5.85.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.85.0
- Changes since 5.84.0:
  * Silence warning about overloaded signal
* Sun Jul  4 2021 christophe@krop.fr
- Update to 5.84.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.84.0
- Changes since 5.83.0:
  * Pump minimum Bison version to 3.0
  * Workaround flatpak having fixed modify date for all files
  * Instantiate a single TimestampChecker in KSycocaPrivate::needsRebuild
  * Remove unused includes
* Sat Jun  5 2021 christophe@krop.fr
- Update to 5.83.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.83.0
- Changes since 5.82.0:
  * Do not crash if there's no Konsole
  * Bump required CMake version to 3.16
  * Call ki18n_install() unconditionally
  * Launch KCMs in kcmshell5 if systemsettings5 is not installed
  * KToolInvocation: deprecate kdeinitExec()
* Sat May  1 2021 christophe@krop.fr
- Update to 5.82.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.82.0
- Changes since 5.81.0:
  * Deprecate KMimeTypeTrader
  * [ktoolinvokation] Port away from KMimeTypeTrader
  * Deprecate KPluginTrader
  * Properly deprecate some KToolInvokation methods
  * Include X-KDE-Wayland-VirtualKeyboard
* Mon Apr  5 2021 christophe@krop.fr
- Update to 5.81.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.81.0
- Changes since 5.80.0:
  * Deprecate KPluginInfo::fromKPartsInstanceName, completely unused
* Sun Mar  7 2021 christophe@krop.fr
- Update to 5.80.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.80.0
- Changes since 5.79.0:
  * Run clang-format
  * Add clang-format pre-commit hook
  * Un-overload databaseChagned() signal
  * src/services/yaac.y: use '%%define api.pure'
* Mon Feb  8 2021 christophe@krop.fr
- Update to 5.79.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.79.0
- Changes since 5.78.0:
  * Deprecate KPluginInfo::dependencies()
  * CMake: Specify add_custom_command() dependencies
  * Explicitly deprecate overload for KToolInvocation::invokeTerminal
  * Add unit test to command parsing in KToolInvocation
  * Add method to get KServicePtr of default terminal application
  * Add method to set workingDirectory of service
  * Add new method to get KServicePtr of default terminal application
* Wed Jan  6 2021 christophe@krop.fr
- Update to 5.78.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.78.0
- Changes since 5.77.0:
  * Add missing includes
  * Properly include QStringList
  * Remove ifdefs, we require Qt 5.14 now
  * silently ignore empty files
  * Remove unused include
  * Fix duplicate detection check
  * KSycoca: avoid database rebuild if XDG_CONFIG_DIRS contains duplicates
  * KSycoca: ensure extrafiles are ordered for comparison (kde#429593)
* Mon Dec  7 2020 christophe@krop.fr
- Update to 5.77.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.77.0
- Changes since 5.76.0:
  * [kapplicationtrader] Fix API docs
  * KSycoca: recreate DB when version < expected version
  * KSycoca: Keep track of resources Files of KMimeAssociation
  * KSycoca: ensure extrafiles are ordered for comparison
  * KSycoca: avoid database rebuild if XDG_CONFIG_DIRS contains
    duplicates
  * Fix duplicate detection check
* Sat Nov  7 2020 christophe@krop.fr
- Update to 5.76.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.76.0
- Changes since 5.75.0:
  * Fix two recent regressions
  * Allow NotShowIn=KDE apps, listed in mimeapps.list, to be used (kde#427469)
  * If include is define in .h remove it if it's defined in .cpp too (scripted)
  * autotests: port kmimeassociationstest to KApplicationTrader
  * Write fallback value for KCM Exec lines with appropriate executable
  * Various fixes
  * Documentation fixes
  * Remove a bit of dead code
  * Solve some minor clazy warnings
* Mon Oct  5 2020 christophe@krop.fr
- Update to 5.75.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.75.0
- Changes since 5.74.0:
  * Fix shadow variable. Reported by cppcheck
  * bring back disableAutoRebuild from the brink (kde#423931)
* Sun Sep  6 2020 christophe@krop.fr
- Update to 5.74.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.74.0
- Changes since 5.73.0:
  * Implement invokeTerminal on Windows with workdir, command and envs
  * Clean forward declaration
  * Fix application preference ordering for mimetypes with multiple inheritance.
  * Remove obsolete COPYING files
  * Bundle the Application servicetype into a qrc file.
  * Fix KApplicationTrader API docs being incompletely generated
  * Expand tilde character when reading working directory (kde#424974)
  * KService: Convert copyright statements to SPDX expressions
  * Cleanup overload
* Sun Aug  2 2020 christophe@krop.fr
- Update to 5.73.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.73.0
- Changes since 5.72.0:
  * Add overload to invoke terminal with ENV variables
  * Use KF-standardized Qt logging categories
  * Use camelcase include. (scripted)
* Sun Jul  5 2020 christophe@krop.fr
- Update to 5.72.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.72.0
- No code change since 5.71.0
* Sun Jun  7 2020 christophe@krop.fr
- Update to 5.71.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.71.0
- Changes since 5.70.0:
  * Add X-KDE-DBUS-Restricted-Interfaces to Application desktop entry fields
  * Use KSERVICE_DEPRECATED_VERSION_BELATED
  * Build with EXCLUDE_DEPRECATED_BEFORE_AND_AT=CURRENT
  * Add missing compiler deprecation tag for 5-args KServiceAction constructor
* Sun May  3 2020 christophe@krop.fr
- Update to 5.70.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.70.0
- Changes since 5.69.0:
  * Deprecate KPluginInfo::service(), since the constructor with a KService is deprecated.
  * newServicePath(): Docs say add prefix but it's actually suffix
* Sun Apr  5 2020 christophe@krop.fr
- Update to 5.69.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.69.0
- Changes since 5.68.0:
  * add @since
  * Add static method to check start condition
  * QAtomicInteger::loadRelaxed/storeRelaxed() are available since Qt 5.14
  * KServiceAction: store parent service
  * KSycoca: avoid hitting an assert when writing a full path into mimeapps.list
  * Properly read the X-Flatpak-RenamedFrom string list from desktop files
  * Fix cmake warning
* Sun Mar  8 2020 christophe@krop.fr
- Update to 5.68.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.68.0.php
- Changes since 5.67.0:
  * Make it compile against qt5.15. SkipEmptyParts is part of Qt::.
  * New query mechanism for applications: KApplicationTrader
* Sun Feb  2 2020 christophe@krop.fr
- Replace %%make_jobs with %%cmake_build.
* Sun Feb  2 2020 christophe@krop.fr
- Update to 5.67.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.67.0.php
- Changes since 5.66.0:
  * autotests: simplify test to use bin/data/menus
  * [autotests] rename test desktop file, so can see the debug output in CI
  * Support multiple values in XDG_CURRENT_DESKTOP
  * [autotest] mkpath() before copy to fix CI failure
  * Deprecated allowAsDefault
  * Make "Default Applications" in mimeapps.list the preferred applications
  * autotests: use local desktop file to avoid relying on konsole
* Sun Jan  5 2020 christophe@krop.fr
- Update to 5.66.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.66.0.php
- Changes since 5.65.0:
  * Remove endl in qDebug, it already adds "\n" + port to Qt::endl when using qt5.15
  * Deprecate KServiceTypeProfile
  * Update the obsolete projects.kde.org URL
  * autotests: remove <QtTest> which includes all of <QtCore>
  * autotests: make ksycoca_xdgdirstest work without /etc/xdg/menus
  * Fix kmimeassociationstest in case of symlinks in the paths
  * Remove dead code in KCTimeFactory and KBuildSycoca
  * Port KPluginTrader away from Q_GLOBAL_STATIC.
* Sun Dec  8 2019 christophe@krop.fr
- Update to 5.65.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.65.0.php
- No code change since 5.64.0
* Sun Nov  3 2019 christophe@krop.fr
- Update to 5.64.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.64.0.php
- Changes since 5.63.0:
  * Theses methods were adding in qt5.15
  * Make it compile against qt5.15 without deprecated method
  * KService: fix kded compilation with -DKF_DISABLE_DEPRECATED_BEFORE_AND_AT=0x053f00
  * Use ECMGenerateExportHeader to manage deprecated API better
* Sun Oct  6 2019 christophe@krop.fr
- Update to 5.63.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.63.0.php
- Changes since 5.62.0:
  * Move Amusement to Games directory instead of Games > Toys (kde#412553)
  * [KService] Add copy constructor.
  * [KService] add workingDirectory(), deprecate path().
* Sat Sep  7 2019 christophe@krop.fr
- Update to 5.62.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.62.0.php
- Changes since 5.61.0:
  * autotests: check that mimetypes defined by kcoreaddons are available
  * Remove unused includes
- Replace foo-devel with cmake(KF5Foo) in build requirements
* Wed Aug  7 2019 christophe@krop.fr
- Update to 5.61.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.61.0.php
- Changes since 5.60.0:
  * Clean up all core related to opening a dummy sycoca, unused.
  * Fix asserts when the sycoca DB is unreadable by user (e.g. root owned)
  * Expose X-KDE-Wayland-Interfaces
  * Fix KService build on Android
  * KService: remove broken concept of global sycoca database
  * Fix infinite recursion when using a dummy DB because ksycoca is inaccessible
  * CMakeLists: add "CONFIG" for better error messages if anything isn't found
  * Deprecate KDBusServiceStarter. All usage in kdepim is now gone, DBus activation is a better solution.
  * Remove very dangerous deletion code with kbuildsycoca5 --global.
  * Allow KAutostart to be constructed using an absolute path
* Fri Jul 19 2019 wbauer@tmo.at
- Don't lower minimum Qt version anymore, it requires 5.11 now
* Sun Jul 14 2019 lbeltrame@kde.org
- Update to 5.60.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.60.0.php
- Changes since 5.59.0:
  * Add X-Flatpak-RenamedFrom as recognized key
  * Install in new logging directory when we use kf5 5.59.0
* Sun Jun  9 2019 lbeltrame@kde.org
- Update to 5.59.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.59.0.php
- Changes since 5.58.0:
  * Fix another assert when the file disappears under us: ASSERT: "ctime != 0"
  * Fix assert (hash != 0) sometimes when a file is deleted by another process
* Wed May 15 2019 lbeltrame@kde.org
- Update to 5.58.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.58.0.php
- No code changes since 5.57.0
* Sun Apr 14 2019 lbeltrame@kde.org
- Update to 5.57.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.57.0.php
- Changes since 5.56.0:
  * Add X-GNOME-UsesNotifications as recognized key
  * Add bison minimum version of 2.4.1 due to %%code
  * [kservice] Make it compile without foreach
  * [kservice] compile without deprecated method
* Sun Mar 10 2019 lbeltrame@kde.org
- Update to 5.56.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.56.0.php
- Changes since 5.55.0:
  * kbuildsycoca5: no need to repeat work of KAboutData::setupCommandLine()
* Fri Feb 15 2019 alarrosa@suse.com
- Downgrade the Qt version requirement to build with 5.9
* Sun Feb 10 2019 lbeltrame@kde.org
- Update to 5.55.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.55.0.php
- Changes since 5.54.0:
  * Build without D-Bus on Android
  * delete copy constructor and assignment operator of some internal classes
  * Suggest people to use K_PLUGIN_CLASS_WITH_JSON
* Mon Jan 14 2019 lbeltrame@kde.org
- Update to 5.54.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.54.0.php
- Changes since 5.53.0:
  * applications.menu: remove unused category X-KDE-Edu-Teaching
  * applications.menu: remove <KDELegacyDirs/>
* Sun Dec  9 2018 lbeltrame@kde.org
- Update to 5.53.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.53.0.php
- Changes since 5.52.0:
  * Use new syntax
* Sun Nov 11 2018 lbeltrame@kde.org
- Update to 5.52.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.52.0.php
- Changes since 5.51.0:
  * Use more explicit constructors with internal classes
  * Use Q_OBJECT with all QObject subclasses (helps debugging introspection)
  * Do not use const reference for enum type argument in internal API
  * Use const ref for non-trivial copy types in internal API
  * Use QLatin1String method overload instead of creating a temporary QString
  * Use QStringLiteral, not QLatin1String, if a final QString is wanted
  * Use QLatin1String, not QString::fromLatin1, in string calculations
  * Use qEnvironmentVariableIntValue
* Tue Oct 16 2018 lbeltrame@kde.org
- Run spec-cleaner
* Mon Oct 15 2018 lbeltrame@kde.org
- Update to 5.51.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.51.0.php
- Changes since 5.50.0:
  * Port deprecated method
  * Make compile with strict flags
  * Fix minor EBN issues
* Thu Sep 13 2018 lbeltrame@kde.org
- Update to 5.50.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.50.0.php
- Changes since 5.49.0:
  * autotests: debug output for CI failure, or for general debugging
  * autotests: rename header and function to match new purpose
  * autotests: also copy applications.menu and set XDG_CONFIG_DIRS so it's found
  * KBuildSycoca: always process application desktop files.
  * autotests: factorize XDG_DATA_DIRS setup in new header, use from 3rd test
  * autotests: don't wait for signal if we already received it (e.g. Windows CI)
  * autotests: fix failure on Windows, QStringLiteral isn't fromUtf8 there...
  * autotests: use data/kservicetypes5 instead of share, so it works on Windows too
  * autotests: use local servicetype desktop files in kservicetest as well
  * autotests: use local copies of kplugininfo.desktop and application.desktop
* Sun Aug 19 2018 christophe@krop.fr
- Update to 5.49.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.49.0.php
- Changes since 5.48.0:
  * Use more nullptr
  * API dox: talk about nullptr, not 0
  * Require out-of-source build
  * Add subseq operator to match sub-sequences
* Mon Jul 16 2018 lbeltrame@kde.org
- Update to 5.48.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.48.0.php
- Changes since 5.47.0:
  * Remove unused key X-KDE-DBus-ModuleName from test service metadata
  * Add missing override
  * Use override
* Tue Jun 12 2018 lbeltrame@kde.org
- Update to 5.47.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.47.0.php
- Changes since 5.46.0:
  * Use override
* Sun May 13 2018 lbeltrame@kde.org
- Update to 5.46.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.46.0.php
- Changes since 5.45.0:
  * warning--
  * Warning--
* Sat Apr 14 2018 lbeltrame@kde.org
- Update to 5.45.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.45.0.php
- Changes since 5.44.0:
  * We depend against 5.8.0
  * API dox: consistently use X-KDE-ServiceTypes instead of ServiceTypes
  * Remove not necessary QtCore and co
  * [API dox] Remove deprecated Encoding=UTF-8 from example for desktop file
* Mon Mar 12 2018 lbeltrame@kde.org
- Update to 5.44.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.44.0.php
- Changes since 5.43.0:
  * None
* Mon Feb 12 2018 lbeltrame@kde.org
- Update to 5.43.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.43.0.php
- Changes since 5.42.0:
  * None
* Tue Jan 16 2018 lbeltrame@kde.org
- Update to 5.42.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.42.0.php
- Changes since 5.41.0:
  * Remove obsolete reviewboardrc file
  * Install categories file + use debug categories when necessary
  * Fix cmake warning
  * autogenerate debug file
* Sun Dec 17 2017 lbeltrame@kde.org
- Update to 5.41.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.41.0.php
- Changes since 5.40.0:
  * Fix compile with QT_NO_CAST_FROM_ASCII
* Mon Nov 13 2017 lbeltrame@kde.org
- Update to 5.40.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.40.0.php
- Changes since 5.39.0:
  * Initialize values
  * Initialize some pointer
* Mon Oct 23 2017 lbeltrame@kde.org
- Update to 5.39.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.39.0.php
- Changes since 5.38.0:
  * None
* Tue Sep 12 2017 lbeltrame@kde.org
- Update to 5.38.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.38.0.php
- Changes since 5.37.0:
  * autotests: fix running tests in parallel
* Sat Aug 12 2017 christophe@krop.fr
- Update to 5.37.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.37.0.php
- Changes since 5.36.0 :
  * API dox: small improvements to example code
  * API dox: fix method used in example code
  * autotests: make it work with CMAKE_RUNTIME_OUTPUT_DIRECTORY being set
  * API dox: use official name "D-Bus" consistently
* Wed Jul 12 2017 lbeltrame@kde.org
- Update to 5.36.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.36.0.php
- Changes since 5.35.0:
  * Fix MSVC warning
  * [FEATURE] Option to build & install QCH file with the public API dox
  * tests: kautostarttest: fix also expected value
  * tests: use cmd.exe as TryExec on Windows
* Sun Jun 11 2017 lbeltrame@kde.org
- Update to 5.35.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.35.0.php
- Changes since 5.34.0:
  * API dox: Use doxygen notation to have comments used
  * API dox: note CamelCase includes by @class tag with more classes
* Mon May 15 2017 fabian@ritter-vogt.de
- Update to 5.34.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.34.0.php
- Changes since 5.33.0:
  * None
- Use %%find_lang --with-man --all-name
* Sat Apr 15 2017 lbeltrame@kde.org
- Update to 5.33.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.33.0.php
- Changes since 5.32.0:
  * Upgrade ECM and KF5 version requirements for 5.33.0 release.
  * Fix 'Not found: ""' terminal messages
  * Upgrade KF5 version to 5.33.0.
  * [autotest] Fix the workaround for inotify-on-overlay-fs so it actually works
  * [autotest] test s-m-i requirement
  * [autotests] add tests for the KService constructors
* Sun Mar 19 2017 lbeltrame@kde.org
- Update to 5.32.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.32.0.php
- Changes since 5.31.0:
  * Commit translations from l10n-kf5
  * Upgrade ECM and KF5 version requirements for 5.32.0 release.
  * further investigation of the kservicetest unittest failure in CI
  * Upgrade KF5 version to 5.32.0.
  * Port some left-over debug output to categorized logging
* Thu Feb  9 2017 hrvoje.senjan@gmail.com
- Update to 5.31.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.31.0.php
* Sun Jan  8 2017 hrvoje.senjan@gmail.com
- Update to 5.30.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.30.0.php
* Sun Dec  4 2016 hrvoje.senjan@gmail.com
- Update to 5.29.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.29.0.php
* Sat Nov  5 2016 hrvoje.senjan@gmail.com
- Update to 5.28.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.28.0.php
* Sun Oct  2 2016 hrvoje.senjan@gmail.com
- Update to 5.27.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.27.0.php
* Tue Sep  6 2016 hrvoje.senjan@gmail.com
- Update to 5.26.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.26.0.php
* Sun Aug  7 2016 hrvoje.senjan@gmail.com
- Update to 5.25.0
  * Qt >= 5.5 is now required
  * applications.menu: remove references to unused categories
  * Always update the Trader parser from yacc/lex sources
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.25.0.php
* Wed Jul  6 2016 hrvoje.senjan@gmail.com
- Update to 5.24.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.24.0.php
* Mon Jun  6 2016 hrvoje.senjan@gmail.com
- Update to 5.23.0
  * Fix associated applications for mimetypes with
    uppercase characters (boo#980046)
  * Lowercase the lookup key for mimetypes,
    to make it case insensitive
  * Fix ksycoca notifications when the DB doesn't exist yet
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.23.0.php
* Sat May  7 2016 hrvoje.senjan@gmail.com
- Update to 5.22.0 (boo#980066)
  * Remove too-strict maximum string length in KSycoca database
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.22.0.php
* Mon Apr  4 2016 hrvoje.senjan@gmail.com
- Update to 5.21.0 (boo#974793)
  * Fix new kbuildsycoca warning, when a mimetype inherits
    from an alias
  * Fix handling of x-scheme-handler/* in mimeapps.list
  * Fix handling of x-scheme-handler/* in mimeapps.list parsing
    (kde#358159)
  * Upgrade Qt version requirement to 5.4.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.21.0.php
* Sun Mar  6 2016 hrvoje.senjan@gmail.com
- Update to 5.20.0 (boo#970856)
  * Simplify code, reduce pointer dereferences,
    container-related improvements
  * Add kmimeassociations_dumper test program,
    inspired by bug 359850
  * Fix chromium/wine apps not loading on some distributions
    (kde#213972)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.20.0.php
* Sun Feb 28 2016 hrvoje.senjan@gmail.com
- Drop totally wrong list-local-mimeapps-last.patch
* Sat Feb  6 2016 hrvoje.senjan@gmail.com
- Update to 5.19.0 (boo#967668)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.19.0.php
- Added list-local-mimeapps-last.patch list local mimeapps.list
  last to QListIterator, so it's   respected before global ones
  (boo#966739)
* Sat Jan  2 2016 hrvoje.senjan@gmail.com
- Update to 5.18.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.18.0.php
* Thu Dec 10 2015 hrvoje.senjan@gmail.com
- Update to 5.17.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.17.0.php
* Sun Nov  8 2015 hrvoje.senjan@gmail.com
- Update to 5.16.0 (boo#955067)
  * KBuildSycoca: always save, even if no change in .desktop file
    was noticed. (kde#353203)
  * Make doctools optional
  * kbuildsycoca: parse all the mimeapps.list files mentioned in
    the new spec.
  * Use largest timestamp in subdirectory as resource
    directory timestamp.
  * Keep MIME types separate when converting KPluginInfo to
    KPluginMetaData
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.16.0.php
* Fri Oct 23 2015 wbauer@tmo.at
- Add dont-show-yast-modules-in-the-applications-menu.patch: hide
  the YaST modules from the application menu (boo#951888)
* Mon Oct  5 2015 hrvoje.senjan@gmail.com
- Update to 5.15.0
  * Use largest timestamp in subdirectory as resource
    directory timestamp.
  * KSycoca: store mtime for every source dir, to detect changes.
    (kde#353036)
  * KServiceTypeProfile: remove unnecessary factory creation.
    (kde#353360)
  * Simplify and speed up KServiceTest::initTestCase.
  * make install name of applications.menu file a cached
    cmake variable
  * KSycoca: ensureCacheValid() should create the db if
    it doesn't exist
  * KSycoca: make global database work after the recent
    timestamp check code
  * KSycoca: change DB filename to include language and
    sha1 of the dirs it's built from.
  * KSycoca: make ensureCacheValid() part of the public API.
  * KSycoca: add a q pointer to remove more singleton usage
  * KSycoca: remove all self() methods for factories, store
    them in KSycoca instead.
  * KBuildSycoca: remove writing of the ksycoca5stamp file.
  * KBuildSycoca: use qCWarning rather than fprintf(stderr, ...)
    or qWarning
  * KSycoca: rebuild ksycoca in process rather than
    executing kbuildsycoca5
  * KSycoca: move all of the kbuildsycoca code into the lib,
    except for main().
  * KSycoca optimization: only watch the file if the app
    connects to databaseChanged()
  * Fix memory leaks in the KBuildSycoca class
  * KSycoca: replace DBus notification with file watching
    using KDirWatch.
  * kbuildsycoca: deprecate option --nosignal.
  * KBuildSycoca: replace dbus-based locking with a lock file.
  * Do not crash when encountering invalid plugin info.
  * Rename headers to _p.h in preparation for move to
    kservice library.
  * Move checkGlobalHeader() within KBuildSycoca::recreate().
  * Remove code for --checkstamps and --nocheckfiles.
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.15.0.php
- Drop menu.patch, no longer needed.
  Pass -DAPPLICATIONS_MENU_NAME="kf5-applications.menu" to cmake instead
* Sat Sep 19 2015 hrvoje.senjan@gmail.com
- Update to 5.14.3
  * Fix timestamp truncation due to unwanted quint64 -> quint32 conversions.
    (kde#352854)
- Bring back Source URL
* Wed Sep 16 2015 hrvoje.senjan@gmail.com
- Update to 5.14.1
  * Revert ksycoca format change for now, for better compatibility
    (kde#352756)
- Temporary comment out Source URL
* Tue Sep  8 2015 hrvoje.senjan@gmail.com
- Update to 5.14.0
  * KSycoca: check timestamps and run kbuildsycoca if needed.
    No kded dependency anymore.
  * Don't close ksycoca right after opening it.
  * KPluginInfo now correctly handles FormFactor metadata
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.14.0.php
* Sat Aug 15 2015 wbauer@tmo.at
- Add kservice-desktop-translations.patch: read translations for
  .desktop files from desktop-translations if they are not in the
  file itself (boo#904524, boo#932158)
* Tue Aug  4 2015 hrvoje.senjan@gmail.com
- Update to 5.13.0
  * The Qt version requirement has been bumped from 5.2 to 5.3
  * Debug output has been ported to categorized output, for less
    noise by default
  * Docbook documentation has been reviewed and updated
  * Fix kbuildsycoca --global
  * KToolInvocation::invokeMailer: fix attachment when we have
    multi attachement
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.13.0.php
* Sun Jul  5 2015 hrvoje.senjan@gmail.com
- Update to 5.12.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.12.0.php
* Sun Jun  7 2015 hrvoje.senjan@gmail.com
- Update to 5.11.0
  * When running as root preserve file ownership on existing
    cache files (kde#342438)
  * Guard against being unable to open stream (kde#342438)
  * Fix check for invalid permissions writing file (kde#342438)
  * Fix querying ksycoca for x-scheme-handler/* pseudo-mimetypes.
    (kde#347353)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.11.0.php
* Sun May  3 2015 hrvoje.senjan@gmail.com
- Update to 5.10.0
  * Fix wrong splitting of entry path (kde#344614)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.10.0.php
* Sun Apr 19 2015 hrvoje.senjan@gmail.com
- Recommend kded package, it is a runtime requirement, but can't
  be marked as Required as it would create a buildcycle
* Sat Apr  4 2015 hrvoje.senjan@gmail.com
- Update to 5.9.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.9.0.php
- Drop no longer needed Requires of the devel subpackage:
  kdbusaddons-devel and ki18n-devel
* Sat Mar  7 2015 hrvoje.senjan@gmail.com
- Update to 5.8.0
  * KPluginInfo: support stringlists as properties
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.8.0.php
* Sun Feb  8 2015 hrvoje.senjan@gmail.com
- Update to 5.7.0
  * Include unknown properties when converting
    KPluginInfo from KService
  * KPluginInfo: fixed properties not being
    copied from KService::Ptr
  * OS X: performance fix for kbuildsycoca4 (skip app bundles)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.7.0.php
* Sat Jan  3 2015 hrvoje.senjan@gmail.com
- Update to 5.6.0
  * Fix build on MSVC.
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.6.0.php
* Sat Dec  6 2014 hrvoje.senjan@gmail.com
- Update to 5.5.0
  * Fix KPluginTrader::query() for old JSON
  * Deprecate kservice_desktop_to_json for
    kcoreaddons_desktop_to_json
  * Implement KPluginTrader::query() using
    KPluginLoader::findPlugins()
  * Fix KPluginInfo::entryPath() being empty
    when not loaded from .desktop
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.5.0.php
* Sun Nov  2 2014 hrvoje.senjan@gmail.com
- Update to 5.4.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.4.0.php
- Drop 0001-Don-t-call-enableTestMode-when-QStandardPaths-isTest.patch,
  merged upstream
* Thu Oct  9 2014 hrvoje.senjan@gmail.com
- Add 0001-Don-t-call-enableTestMode-when-QStandardPaths-isTest.patch
  from upstream: fixes bug where kded would be called in test mode,
  which made it use ~/.qttest as home dir
* Sat Oct  4 2014 hrvoje.senjan@gmail.com
- Update to 5.3.0
  * Many many fixes to KPluginInfo
  * Add functions to convert between lists KPluginMetaData
    and KPluginInfo
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.3.0.php
* Tue Sep  9 2014 hrvoje.senjan@gmail.com
- Update to 5.2.0
  * For more details please see:
    http://kde.org/announcements/kde-frameworks-5.2.php
* Sat Aug  2 2014 hrvoje.senjan@gmail.com
- Update to 5.1.0
  * For more details please see:
    http://www.kde.org/announcements/kde-frameworks-5.1.php
* Fri Jul 11 2014 hrvoje.senjan@gmail.com
- Define kf5_version within package
* Tue Jul  1 2014 hrvoje.senjan@gmail.com
- Update to 5.0.0
  * Final release of KDE Frameworks 5
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/kde-frameworks-5.0.php
* Sun Jun  1 2014 hrvoje.senjan@gmail.com
- Update to 4.100.0
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-beta3.php
- Add baselibs.conf
* Sun May  4 2014 hrvoje.senjan@gmail.com
- Update to 4.99.0
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-beta2.php
* Sat Mar 29 2014 hrvoje.senjan@gmail.com
- Update to 4.98.0
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-beta1.php
* Tue Mar  4 2014 hrvoje.senjan@gmail.com
- Update to 4.97.0:
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-alpha2.php
* Sat Feb  8 2014 hrvoje.senjan@gmail.com
- Init kservice package
